#include "xspips.h"

XSpiPs_Config XSpiPs_ConfigTable[] __attribute__ ((section (".drvcfg_sec"))) = {

	{
		"cdns,spi-r1p6", /* compatible */
		0xff040000, /* reg */
		0xbebc149, /* xlnx,spi-clk-freq-hz */
		0x0, /* fifo-depth */
		0x4010, /* interrupts */
		0xf9000000 /* interrupt-parent */
	},
	 {
		 NULL
	}
};